/***************************************************************************
 *   Copyright (c) 2016 Werner Mayer <wmayer[at]users.sourceforge.net>     *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#include "PreCompiled.h"

#include "Application.h"
#include "Document.h"
#include "TransactionObject.h"
#include "ViewProviderDocumentObject.h"


using namespace Gui;


TYPESYSTEM_SOURCE_ABSTRACT(Gui::TransactionViewProvider, App::TransactionObject)

TransactionViewProvider::TransactionViewProvider()
{
}

TransactionViewProvider::~TransactionViewProvider()
{
}

void TransactionViewProvider::applyNew(App::Document& Doc, App::TransactionalObject* pcObj)
{
    if (status == New) {
        Gui::Document* doc = Application::Instance->getDocument(&Doc);
        if (doc) {
            doc->addViewProvider(static_cast<ViewProviderDocumentObject*>(pcObj));
        }
    }
}

void TransactionViewProvider::applyDel(App::Document& Doc, App::TransactionalObject* pcObj)
{
    // nothing to do here
    Q_UNUSED(Doc);
    Q_UNUSED(pcObj);
}
